
# Slot: negatively correlated with


holds between any two named thing entities "correlated with" one another in a negative manner.

URI: [biolink:negatively_correlated_with](https://w3id.org/biolink/vocab/negatively_correlated_with)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [correlated with](correlated_with.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:negative_correlation |

